# fderiv package

# Introduction
This package contains derivative function.It calculates the derivatives of a given arrays of x values and function values. It returns first and second order derivatives using the five point method.     
** The minimum size of array should be 5 for both x and y values.**

# Files
fderiv.py

# Installation
$ pip install fderiv
 
# Usage
import fderiv as fd
first-derivative, second-derivative = fd.fderiv(x, y)
